# SHL-Indonesia-Earthquake's-Report
This is a live earthquake report from Indonesian Agency for Meteorology, Climatology, and Geophysics' s data

## How this Program Work?
this package will extract from 	[BMKG](https://www.bmkg.go.id)

this program will retrieve data from bmkg using the beautiful4 library and request.

# AUTHOR 
Muhammad Sahal Nurdin
Computer Science Students at Gunadarma University